## S'assurer que l'espace de travail est bien défini (commande setwd, comme : set working directory) et que le fichier de données s'y trouve
## Pour exécuter l'ensemble du script, bouton "Source" au dessus à droite
## Pour exécuter ligne par ligne, bouton "Run" ou CTRL-Entrée après avoir placé le curseur sur la ligne désirée

## Chargement des données
## Format CSV français ("csv2")
## - séparateur de champs :   ;
## - séparateur de décimale :   ,
swan <- read.csv2("Swan_Ganz-sans_erreur.csv")


## Première exploration
str(swan)

## Les variables binaires 0/1 sont considérées à tort comme numériques -> on les transforme en facteur (qualit)
for (v in c("atcd_cancer", "atcd_cardio", "atcd_demence", "atcd_IC", "atcd_IDM", "atcd_IH", "atcd_immun", "atcd_IRespC", "atcd_psy", "atcd_renal", "Swan_Ganz")) {
    swan[,v] <- factor(swan[,v])
}



####################################
## Résumé de toutes les variables ##
####################################

## NB : la fonction print() sert à ce que les résultats numériques (non graphiques) s'affichent dans la console quand on exécute le script
print(summary(swan))

## Si le package prettyR est installé (install.package("prettyR")) :
library("prettyR")
describe(swan)
## Personnalisé : sans les variables de date (pas d'intérêt ici), affichage d'autres paramètres : valeurs minimales et maximales ++
describe(swan[,-which(names(swan) %in% c("date_deces", "date_inclusion"))],
         num.desc = c("mean", "sd", "median", "min", "max", "valid.n"))


##################
## Par variable ##
##################

####
## Analyse d'une variable quantitative (par ex. age)

## Indicateurs numériques (moyenne,...)
print(summary(swan$age))
## Histogramme
hist(swan$age)
## Le même en plus joli
hist(swan$age, main = "Distribution de l'âge", xlab = "âge (années)", ylab = "effectif", col = "grey")
## boîte à moustache
boxplot(swan$age, main = "Distribution de l'âge", ylab = "âge (années)", col = "grey")

####
## Analyse d'une variable qualitative (par ex. catégorie diagnostique)
## Tableau d'effectifs
print(table(swan$categorie_DP))
## Tableau de proportion
print(prop.table(table(swan$categorie_DP)))
## Pourcentage : x100 tout simplement
print(prop.table(table(swan$categorie_DP))*100)

## Diagramme en barre
barplot(table(swan$categorie_DP), col="grey", main="Catégorie de\ndiagnostic principal", xlab="niveau de risque suicidaire", ylab="effectif")
## Version camembert (pie chart)
pie(table(swan$categorie_DP), main="Distribution du diagnostic principal")
## -> déconseillé quand plus de 3 modalités !
## Par contre, OK pour variables binaires
pie(table(swan$Swan_Ganz), main="Exposition à la Swan Ganz")




####
## Toutes les variables d'un coup

for(v in names(swan)) {
    if (! v %in% c("date_deces", "date_inclusion")) {
        ## Si variable numérique (integer ou numeric), histogramme et boxplot
        if (class(swan[,v]) %in% c("numeric", "integer")) {
            ## Fenêtre graphique : 1 ligne, 2 colonnes -> 2 graphiques l'un à côté de l'autre
            par(mfrow = c(1,2))
            hist(swan[,v],
                 col = "gray",
                 main = v,
                 xlab = v,
                 ylab = "effectifs")
            boxplot(swan[,v],
                    col = "gray",
                    main = v,
                    xlab = "",
                    ylab = v)
        }
        ## Sinon : diagramme en barre (+ affichage valeurs manquantes : useNA)
        else {
            par(mfrow = c(1,1))
            barplot(table(swan[,v], useNA = "ifany"),
                    col = "gray",
                    main = v,
                    xlab = "",
                    ylab = "effectifs")
        }
    }
}

par(mfrow = c(1,1))


###########################
## Détection des erreurs ##
###########################

## Numéro de ligne avec âge aberrant
which(swan$age > 110)

## atcd_IDM côté "2"
which(swan$atcd_IDM == 2)

## categorie_DP = "ARF " (attention à l'espace !)
which(swan$categorie_DP == "ARF ")



########################
## Analyses bivariées ##
########################

####
## Croisement de 2 variables qualitatives (par ex. Swan_Ganz et  categorie_DP)

print(table(swan$categorie_DP, swan$Swan_Ganz))
## Affichage plus explicite
print(table(swan$categorie_DP, swan$Swan_Ganz,
            deparse.level = 2))
## Proportion
## - sur le total
print(prop.table(table(swan$categorie_DP, swan$Swan_Ganz, deparse.level = 2))*100)
## - par ligne
print(prop.table(table(swan$categorie_DP, swan$Swan_Ganz, deparse.level = 2),
                 margin = 1)*100)
## - par colonne
print(prop.table(table(swan$categorie_DP, swan$Swan_Ganz, deparse.level = 2),
                 margin = 2)*100)
## - en ligne, arrondi à un chiffre après la virgule
print(round(prop.table(table(swan$categorie_DP, swan$Swan_Ganz, deparse.level = 2),
                       margin = 1)*100,
            digits = 1))

## Diagramme en barre avec une légende (position en haut à droite, sans cadre dessiné autour)
## - regroupement par modalité de la variable "categorie_DP"
barplot(table(swan$Swan_Ganz, swan$categorie_DP), beside = T, legend.text = c("contrôles", "Swan Ganz"), args.legend = list(x="topright", bty="n"))
## - regroupement par modalité de la variable "Swan_Ganz"
barplot(table(swan$categorie_DP, swan$Swan_Ganz), beside = T, legend.text = levels(swan$categorie_DP), args.legend = list(x="topright", bty="n"))


####
## Croisement variable qualitative - variable quantitative (par ex. Swan_Ganz et age)

## Moyenne de l'âge chez les exposés
mean(swan[swan$Swan_Ganz == "1", "age"])
## Moyenne de l'âge chez les non exposés
mean(swan[swan$Swan_Ganz == "0", "age"])

## Représentation : boîte à moustaches
boxplot(age ~ Swan_Ganz,
        data = swan,
        main = "Âge selon l'exposion\nà la Swan Ganz",
        col = "gray",
        ylab = "âge (année)")

## Ex poids ~ sexe
boxplot(poids ~ sexe,
        data = swan,
        col = "gray",
        main = "Poids selon le sexe",
        ylab = "poids (kg)")

####
## Croisement de 2 variables quantitatives (par ex. 

plot(swan$PaCO2, swan$pH,
     main = "Relation entre PaCO2 et pH",
     xlab = "PaCO2",
     ylab = "pH")
## Équivalent à :
plot(pH ~ PaCO2, data = swan,
     main = "Relation entre PaCO2 et pH",
     xlab = "PaCO2",
     ylab = "pH")

## Distinction antécédent respi ou non
plot(pH ~ PaCO2, data = swan[swan$atcd_IRespC == 1,],
     main = "Relation entre PaCO2 et pH",
     xlab = "PaCO2",
     ylab = "pH",
     col = "red",
     xlim = range(swan$PaCO2),
     ylim = range(swan$pH))
points(pH ~ PaCO2,
       data = swan[swan$atcd_IRespC == 0,],
       col = "blue")
legend("topright",
       legend = c("insuffisance respi chro", "contrôles"),
       fill = c("red", "blue"),
       bty = "n")
## Représentation de la régression linéaire
abline(lm(pH ~ PaCO2, data = swan[swan$atcd_IRespC == 1,]),
       col = "red")
abline(lm(pH ~ PaCO2, data = swan[swan$atcd_IRespC == 0,]),
       col = "blue")
## Conclusion : bicar mon ami ?

